Modified: openoffice/trunk/main/sfx2/source/doc/docinsert.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/docinsert.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/docinsert.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/docinsert.cxx Sat Jun  8 20:30:34 2019
@@ -205,7 +205,7 @@ IMPL_LINK( DocumentInserter, DialogClose
                TemplateDescription::FILESAVE_AUTOEXTENSION_PASSWORD == nDlgType
             || 
TemplateDescription::FILESAVE_AUTOEXTENSION_PASSWORD_FILTEROPTIONS == nDlgType 
);
 
-        // check, wether or not we have to display a password box
+        // check, whether or not we have to display a password box
         if ( bHasPassword && m_pFileDlg->IsPasswordEnabled() )
         {
             try

Modified: openoffice/trunk/main/sfx2/source/doc/doctempl.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/doctempl.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/doctempl.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/doctempl.cxx Sat Jun  8 20:30:34 2019
@@ -2707,7 +2707,7 @@ sal_Bool getTextProperty_Impl( Content&
     {
         uno::Reference< XPropertySetInfo > aPropInfo = 
rContent.getProperties();
 
-        // check, wether or not the property exists
+        // check, whether or not the property exists
         if ( !aPropInfo.is() || !aPropInfo->hasPropertyByName( rPropName ) )
         {
             return sal_False;

Modified: openoffice/trunk/main/sfx2/source/doc/doctemplates.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/doc/doctemplates.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/doc/doctemplates.cxx (original)
+++ openoffice/trunk/main/sfx2/source/doc/doctemplates.cxx Sat Jun  8 20:30:34 
2019
@@ -1001,7 +1001,7 @@ sal_Bool SfxDocTplService_Impl::setPrope
         Any aPropValue( rPropValue );
         uno::Reference< XPropertySetInfo > aPropInfo = 
rContent.getProperties();
 
-        // check, wether or not the property exists, create it, when not
+        // check, whether or not the property exists, create it, when not
         if ( !aPropInfo.is() || !aPropInfo->hasPropertyByName( rPropName ) )
         {
             uno::Reference< XPropertyContainer > xProperties( rContent.get(), 
UNO_QUERY );
@@ -1068,7 +1068,7 @@ sal_Bool SfxDocTplService_Impl::getPrope
     {
         uno::Reference< XPropertySetInfo > aPropInfo = 
rContent.getProperties();
 
-        // check, wether or not the property exists
+        // check, whether or not the property exists
         if ( !aPropInfo.is() || !aPropInfo->hasPropertyByName( rPropName ) )
         {
             return sal_False;
@@ -1472,7 +1472,7 @@ sal_Bool SfxDocTplService_Impl::addGroup
 {
        ::osl::MutexGuard aGuard( maMutex );
 
-       // Check, wether or not there is a group with this name
+       // Check, whether or not there is a group with this name
        Content          aNewGroup;
        OUString                aNewGroupURL;
        INetURLObject   aNewGroupObj( maRootURL );
@@ -1766,7 +1766,7 @@ sal_Bool SfxDocTplService_Impl::storeTem
 {
     ::osl::MutexGuard aGuard( maMutex );
 
-    // Check, wether or not there is a group with this name
+    // Check, whether or not there is a group with this name
     // Return false, if there is no group with the given name
     Content         aGroup, aTemplate, aTargetGroup, aTemplateToRemove;
     OUString        aGroupURL, aTemplateURL, aTemplateToRemoveTargetURL;
@@ -1958,7 +1958,7 @@ sal_Bool SfxDocTplService_Impl::addTempl
 {
     ::osl::MutexGuard aGuard( maMutex );
 
-    // Check, wether or not there is a group with this name
+    // Check, whether or not there is a group with this name
     // Return false, if there is no group with the given name
     Content         aGroup, aTemplate, aTargetGroup;
     OUString        aGroupURL, aTemplateURL;
@@ -2110,7 +2110,7 @@ sal_Bool SfxDocTplService_Impl::removeTe
 {
     ::osl::MutexGuard aGuard( maMutex );
 
-    // Check, wether or not there is a group with this name
+    // Check, whether or not there is a group with this name
     // Return false, if there is no group with the given name
     Content         aGroup, aTemplate;
     OUString        aGroupURL, aTemplateURL;
@@ -2163,7 +2163,7 @@ sal_Bool SfxDocTplService_Impl::renameTe
 {
     ::osl::MutexGuard aGuard( maMutex );
 
-    // Check, wether or not there is a group with this name
+    // Check, whether or not there is a group with this name
     // Return false, if there is no group with the given name
     Content         aGroup, aTemplate;
     OUString        aGroupURL, aTemplateURL;

Modified: openoffice/trunk/main/sfx2/source/view/ipclient.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/view/ipclient.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/view/ipclient.cxx (original)
+++ openoffice/trunk/main/sfx2/source/view/ipclient.cxx Sat Jun  8 20:30:34 2019
@@ -746,7 +746,7 @@ void SfxInPlaceClient::SetObject( const
 
     if ( rObject.is() )
     {
-        // as soon as an object was connected to a client it has to be checked 
wether the object wants
+        // as soon as an object was connected to a client it has to be checked 
whether the object wants
         // to be activated
         rObject->addStateChangeListener( uno::Reference < 
embed::XStateChangeListener >( m_pImp->m_xClient, uno::UNO_QUERY ) );
         rObject->addEventListener( uno::Reference < document::XEventListener 
>( m_pImp->m_xClient, uno::UNO_QUERY ) );

Modified: openoffice/trunk/main/sfx2/source/view/viewfrm.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/sfx2/source/view/viewfrm.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sfx2/source/view/viewfrm.cxx (original)
+++ openoffice/trunk/main/sfx2/source/view/viewfrm.cxx Sat Jun  8 20:30:34 2019
@@ -2397,7 +2397,7 @@ sal_Bool SfxViewFrame::SwitchToViewShell
         OSL_PRECOND( pOldSh, "SfxViewFrame::SwitchToViewShell_Impl: that's 
called *switch* (not for *initial-load*) for a reason" );
         if ( pOldSh )
         {
-            // ask wether it can be closed
+            // ask whether it can be closed
             if ( !pOldSh->PrepareClose( sal_True ) )
                 return sal_False;
 

Modified: openoffice/trunk/main/shell/source/unix/exec/shellexec.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/shell/source/unix/exec/shellexec.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/form/fmundo.cxx (original)
+++ openoffice/trunk/main/svx/source/form/fmundo.cxx Sat Jun  8 20:30:34 2019
@@ -671,7 +671,7 @@ void SAL_CALL FmXUndoEnvironment::proper
                }
 
                // now we have access to the cached info about the property 
affected
-               // and are able to decide wether or not we need an undo action
+               // and are able to decide whether or not we need an undo action
 
         bool bAddUndoAction = rModel.IsUndoEnabled();
         // no UNDO for transient/readonly properties

Modified: openoffice/trunk/main/sw/source/core/doc/htmltbl.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/core/doc/htmltbl.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/core/doc/htmltbl.cxx (original)
+++ openoffice/trunk/main/sw/source/core/doc/htmltbl.cxx Sat Jun  8 20:30:34 
2019
@@ -1273,7 +1273,7 @@ void SwHTMLTableLayout::AutoLayoutPass2(
                nAbsTabWidth = IsTopTable() ? MAX_TABWIDTH : nAbsAvail;
                nRelTabWidth = (nRelAvail ? nRelAvail : nAbsTabWidth );
 
-               // First of all, we check wether we can fit the layout 
constrains,
+               // First of all, we check whether we can fit the layout 
constrains,
                // that are: Every cell's width excluding the borders must be 
at least
                // MINLAY:
 

Modified: openoffice/trunk/main/sw/source/ui/inc/swuiidxmrk.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/ui/inc/swuiidxmrk.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/ui/inc/swuiidxmrk.hxx (original)
+++ openoffice/trunk/main/sw/source/ui/inc/swuiidxmrk.hxx Sat Jun  8 20:30:34 
2019
@@ -116,7 +116,7 @@ class SwIndexMarkDlg : public Window
        sal_Bool                        bPhoneticED1_ChangedByUser;
        sal_Bool                        bPhoneticED2_ChangedByUser;
        LanguageType    nLangForPhoneticReading; //Language of current text 
used for phonetic reading proposal
-       sal_Bool                        bIsPhoneticReadingEnabled; //this value 
states wether phopentic reading is enabled in principle dependend of global cjk 
settings and language of current entry
+       sal_Bool                        bIsPhoneticReadingEnabled; //this value 
states whether phopentic reading is enabled in principle dependend of global 
cjk settings and language of current entry
        com::sun::star::uno::Reference< 
com::sun::star::i18n::XExtendedIndexEntrySupplier >
                                        xExtendedIndexEntrySupplier;
 

Modified: openoffice/trunk/main/sw/source/ui/index/swuiidxmrk.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/sw/source/ui/index/swuiidxmrk.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/sw/source/ui/index/swuiidxmrk.cxx (original)
+++ openoffice/trunk/main/sw/source/ui/index/swuiidxmrk.cxx Sat Jun  8 20:30:34 
2019
@@ -989,7 +989,7 @@ void SwIndexMarkDlg::UpdateDialog()
 }
 
 /*--------------------------------------------------------------------
-        Remind wether the edit boxes for Phonetic reading are changed manually
+        Remind whether the edit boxes for Phonetic reading are changed manually
  --------------------------------------------------------------------*/
 
 IMPL_LINK( SwIndexMarkDlg, PhoneticEDModifyHdl, Edit *, pEdit )

Modified: openoffice/trunk/main/tools/inc/tools/debug.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/tools/inc/tools/debug.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/tools/inc/tools/debug.hxx (original)
+++ openoffice/trunk/main/tools/inc/tools/debug.hxx Sat Jun  8 20:30:34 2019
@@ -248,7 +248,7 @@ inline sal_uIntPtr DbgIsErrorOut()
         return sal_False;
 }
 
-inline sal_uIntPtr DbgGetErrorOut()   // Testtool: test wether to collect 
OSL_ASSERTions as well
+inline sal_uIntPtr DbgGetErrorOut()   // Testtool: test whether to collect 
OSL_ASSERTions as well
 {
     DbgData* pData = DbgGetData();
     if ( pData )

Modified: openoffice/trunk/main/ucb/source/cacher/cachedcontentresultsetstub.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/ucb/source/cacher/cachedcontentresultsetstub.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/ucb/source/cacher/cachedcontentresultsetstub.cxx 
(original)
+++ openoffice/trunk/main/ucb/source/cacher/cachedcontentresultsetstub.cxx Sat 
Jun  8 20:30:34 2019
@@ -446,7 +446,7 @@ void SAL_CALL CachedContentResultSetStub
 
                if(!bFirstPropagationDone)
                {
-                       //check wether the properties 'FetchSize' and 
'FetchDirection' do exist
+                       //check whether the properties 'FetchSize' and 
'FetchDirection' do exist
                        
                        Reference< XPropertySetInfo > xPropertySetInfo = 
getPropertySetInfo();
                        sal_Bool bHasSize = 
xPropertySetInfo->hasPropertyByName( m_aPropertyNameForFetchSize ); 

Modified: openoffice/trunk/main/unotools/source/ucbhelper/ucblockbytes.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/unotools/source/ucbhelper/ucblockbytes.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/unotools/source/ucbhelper/ucblockbytes.cxx (original)
+++ openoffice/trunk/main/unotools/source/ucbhelper/ucblockbytes.cxx Sat Jun  8 
20:30:34 2019
@@ -953,7 +953,7 @@ static sal_Bool UCBOpenContentSync(
        if(xContId.is())
                aScheme = xContId->getContentProviderScheme();
 
-    // now determine wether we use a timeout or not;
+    // now determine whether we use a timeout or not;
     if( ! aScheme.equalsIgnoreAsciiCaseAscii("http")                &&
                ! aScheme.equalsIgnoreAsciiCaseAscii("https")                &&
         ! aScheme.equalsIgnoreAsciiCaseAscii("vnd.sun.star.webdav") &&

Modified: openoffice/trunk/main/vcl/inc/vcl/fontmanager.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/vcl/fontmanager.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/vcl/fontmanager.hxx (original)
+++ openoffice/trunk/main/vcl/inc/vcl/fontmanager.hxx Sat Jun  8 20:30:34 2019
@@ -670,13 +670,13 @@ public:
         virtual bool isCanceled() = 0;
     };
 
-    // checks wether font import would fail due to no writeable directory
+    // checks whether font import would fail due to no writeable directory
     bool checkImportPossible() const;
     // expects system paths not UNC paths
     // returns the number of fonts successfully imported
     int importFonts( const std::list< rtl::OString >& rFiles, bool bLinkOnly = 
false, ImportFontCallback* pCallback = NULL );
 
-    // check wether changeFontProperties would fail due to not writable 
fonts.dir
+    // check whether changeFontProperties would fail due to not writable 
fonts.dir
     bool checkChangeFontPropertiesPossible( fontID nFont ) const;
     // change fonts.dir entry for font
     bool changeFontProperties( fontID nFont, const rtl::OUString& rXLFD );

Modified: openoffice/trunk/main/vcl/inc/vcl/outdev.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/inc/vcl/outdev.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/inc/vcl/outdev.hxx (original)
+++ openoffice/trunk/main/vcl/inc/vcl/outdev.hxx Sat Jun  8 20:30:34 2019
@@ -907,7 +907,7 @@ public:
     the OutDevViewType should be set to 'OUTDEV_VIEWTYPE_PRINTPREVIEW'.
 
     A View than can make painting decisions dependent on this OutDevViewType.
-    E.g. text colors need to be handled different, dependent on wether it's a 
PrintPreview or not. (see #106611# for more)
+    E.g. text colors need to be handled different, dependent on whether it's a 
PrintPreview or not. (see #106611# for more)
     */
     void                SetOutDevViewType( OutDevViewType eOutDevViewType ) { 
meOutDevViewType=eOutDevViewType; }
     OutDevViewType      GetOutDevViewType() const { return meOutDevViewType; }

Modified: openoffice/trunk/main/vcl/source/window/window.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/source/window/window.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/source/window/window.cxx (original)
+++ openoffice/trunk/main/vcl/source/window/window.cxx Sat Jun  8 20:30:34 2019
@@ -362,7 +362,7 @@ void Window::ImplInitAppFontData( Window
     // platforms
     if( pSVData->maNWFData.mbNoFocusRects )
     {
-        // try to find out wether there is a large correction
+        // try to find out whether there is a large correction
         // of control sizes, if yes, make app font scalings larger
         // so dialog positioning is not completely off
         ImplControlValue aControlValue;

Modified: openoffice/trunk/main/vcl/unx/generic/app/saldisp.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/generic/app/saldisp.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/generic/app/saldisp.cxx (original)
+++ openoffice/trunk/main/vcl/unx/generic/app/saldisp.cxx Sat Jun  8 20:30:34 
2019
@@ -231,7 +231,7 @@ static sal_Bool sal_GetVisualInfo( Displ
 
 // ---------------------------------------------------------------------------
 
-// check wether displaystring is in format N.M or N. or just N
+// check whether displaystring is in format N.M or N. or just N
 // with N and M beeing natural numbers
 static sal_Bool
 sal_IsDisplayNumber( const char *pDisplayString )

Modified: openoffice/trunk/main/vcl/unx/generic/dtrans/X11_selection.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/generic/dtrans/X11_selection.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/generic/dtrans/X11_selection.cxx (original)
+++ openoffice/trunk/main/vcl/unx/generic/dtrans/X11_selection.cxx Sat Jun  8 
20:30:34 2019
@@ -3013,7 +3013,7 @@ int SelectionManager::getXdndVersion( XL
                                pBytes = NULL;
                                if( rProxy != None )
                                {
-                                       // now check proxy wether it points to 
itself
+                                       // now check proxy whether it points to 
itself
                                        XGetWindowProperty( m_pDisplay, rProxy, 
m_nXdndProxy, 0, 1, False, XA_WINDOW,
                                                                                
&nType, &nFormat, &nItems, &nBytes, &pBytes );
                                        if( pBytes )

Modified: openoffice/trunk/main/vcl/unx/generic/fontmanager/fontmanager.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/generic/fontmanager/fontmanager.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/generic/fontmanager/fontmanager.cxx (original)
+++ openoffice/trunk/main/vcl/unx/generic/fontmanager/fontmanager.cxx Sat Jun  
8 20:30:34 2019
@@ -835,7 +835,7 @@ bool PrintFontManager::PrintFont::readAf
     else if( m_aEncoding == RTL_TEXTENCODING_DONTKNOW )
         m_aEncoding = RTL_TEXTENCODING_ADOBE_STANDARD;
 
-    // try to parse the font name and decide wether it might be a
+    // try to parse the font name and decide whether it might be a
     // japanese font. Who invented this PITA ?
     OUString aPSNameLastToken( aPSName.copy( aPSName.lastIndexOf( '-' )+1 ) );
     if( ! aPSNameLastToken.compareToAscii( "H" )    ||

Modified: openoffice/trunk/main/vcl/unx/generic/gdi/salprnpsp.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/generic/gdi/salprnpsp.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/generic/gdi/salprnpsp.cxx (original)
+++ openoffice/trunk/main/vcl/unx/generic/gdi/salprnpsp.cxx Sat Jun  8 20:30:34 
2019
@@ -977,7 +977,7 @@ sal_Bool PspSalPrinter::StartJob(
         m_aJobData.setCollate( bCollate );
     }
 
-       // check wether this printer is configured as fax
+       // check whether this printer is configured as fax
     int nMode = 0;
        const PrinterInfo& rInfo( PrinterInfoManager::get().getPrinterInfo( 
m_aJobData.m_aPrinterName ) );
     sal_Int32 nIndex = 0;

Modified: openoffice/trunk/main/vcl/unx/generic/printergfx/psheader.ps
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/generic/printergfx/psheader.ps?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/generic/printergfx/psheader.ps (original)
+++ openoffice/trunk/main/vcl/unx/generic/printergfx/psheader.ps Sat Jun  8 
20:30:34 2019
@@ -53,7 +53,7 @@ begin
                                        currentfile 1 string readstring % s bool
                                        pop                                     
                        % s
                                        0 get                                   
                % s[0]
-                                                                               
                        % --- check wether s[0] is CR, LF ...
+                                                                               
                        % --- check whether s[0] is CR, LF ...
                                        dup 32 gt                               
                % s > ' ' ? then read on
                                        { exit }
                                        { pop  }

Modified: openoffice/trunk/main/vcl/unx/headless/svpprn.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/vcl/unx/headless/svpprn.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/vcl/unx/headless/svpprn.cxx (original)
+++ openoffice/trunk/main/vcl/unx/headless/svpprn.cxx Sat Jun  8 20:30:34 2019
@@ -865,7 +865,7 @@ sal_Bool PspSalPrinter::StartJob(
         m_aJobData.setCollate( bCollate );
     }
 
-       // check wether this printer is configured as fax
+       // check whether this printer is configured as fax
     int nMode = 0;
        const PrinterInfo& rInfo( PrinterInfoManager::get().getPrinterInfo( 
m_aJobData.m_aPrinterName ) );
     sal_Int32 nIndex = 0;

Modified: 
openoffice/trunk/main/wizards/com/sun/star/wizards/ui/SortingComponent.java
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/com/sun/star/wizards/ui/SortingComponent.java?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/com/sun/star/wizards/ui/SortingComponent.java 
(original)
+++ openoffice/trunk/main/wizards/com/sun/star/wizards/ui/SortingComponent.java 
Sat Jun  8 20:30:34 2019
@@ -262,7 +262,7 @@ public class SortingComponent
                     SortFieldNames.add(new String[]{CurFieldName,iCurState == 
1 ? PropertyNames.ASC :"DESC" });
                 }
             }
-            // When searching for a duplicate entry we can neglect wether the 
entries are to be sorted ascending or descending
+            // When searching for a duplicate entry we can neglect whether the 
entries are to be sorted ascending or descending
             // TODO for the future we should deliver a messagebox when two 
different sorting modes have been applied to one field
             int iduplicate = 
JavaTools.getDuplicateFieldIndex(SortDescriptions.toArray(new 
String[SortDescriptions.size()]));
             if (iduplicate != -1)

Modified: openoffice/trunk/main/wizards/source/tools/Misc.xba
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/wizards/source/tools/Misc.xba?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/wizards/source/tools/Misc.xba (original)
+++ openoffice/trunk/main/wizards/source/tools/Misc.xba Sat Jun  8 20:30:34 2019
@@ -137,8 +137,8 @@ Dim sProdName as String
 End Function
 
 
-&apos; Opens a Document, checks beforehand, wether it has to be loaded
-&apos; or wether it is already on the desktop.
+&apos; Opens a Document, checks beforehand, whether it has to be loaded
+&apos; or whether it is already on the desktop.
 &apos; If the parameter bDisposable is set to False then then returned document
 &apos; should not be disposed afterwards, because it is already opened.
 Function OpenDocument(DocPath as String, Args(), Optional bDisposable as 
Boolean)

Modified: openoffice/trunk/main/xmerge/source/inc/antbuild.properties
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/xmerge/source/inc/antbuild.properties?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/xmerge/source/inc/antbuild.properties (original)
+++ openoffice/trunk/main/xmerge/source/inc/antbuild.properties Sat Jun  8 
20:30:34 2019
@@ -23,7 +23,7 @@
 # x-no-translate
 build.sysclasspath=ignore
 
-# set wether we want to compile with or without deprecation
+# set whether we want to compile with or without deprecation
 deprecation=on
 
 src.dir=${basedir}/java

Modified: openoffice/trunk/main/xmerge/workben/build.xml
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/xmerge/workben/build.xml?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/xmerge/workben/build.xml (original)
+++ openoffice/trunk/main/xmerge/workben/build.xml Sat Jun  8 20:30:34 2019
@@ -56,7 +56,7 @@
         <pathelement location="${env.XERCES_JAR}"/>
     </path>
 
-    <!-- set wether we want to compile with or without deprecation -->
+    <!-- set whether we want to compile with or without deprecation -->
     <property name="deprecation" value="on"/>
 
     <!-- ================================================================= -->

Modified: openoffice/trunk/main/xmloff/source/chart/SchXMLChartContext.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/xmloff/source/chart/SchXMLChartContext.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/xmloff/source/chart/SchXMLChartContext.hxx (original)
+++ openoffice/trunk/main/xmloff/source/chart/SchXMLChartContext.hxx Sat Jun  8 
20:30:34 2019
@@ -133,7 +133,7 @@ private:
        /**     @descr  This method bundles some settings to the chart model 
and executes them with
                        a locked controller.  This includes setting the chart 
type.
                @param  aServiceName The name of the service the diagram is 
initialized with.
-               @param  bSetWitchData   Indicates wether the data set takes 
it's data series from
+               @param  bSetWitchData   Indicates whether the data set takes 
it's data series from
                        rows or from columns.
        */
        void    InitChart       (const ::rtl::OUString & rChartTypeServiceName,

Modified: openoffice/trunk/main/xmloff/source/meta/xmlversion.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/xmloff/source/meta/xmlversion.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/xmloff/source/meta/xmlversion.cxx (original)
+++ openoffice/trunk/main/xmloff/source/meta/xmlversion.cxx Sat Jun  8 20:30:34 
2019
@@ -367,7 +367,7 @@ void SAL_CALL XMLVersionListPersistence:
                 
OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.xml.sax.Writer"))));
         DBG_ASSERT( xWriter.is(), "com.sun.star.xml.sax.Writer service 
missing" );
 
-        // check wether there's already a sub storage with the version info
+        // check whether there's already a sub storage with the version info
         // and delete it
         OUString sVerName( RTL_CONSTASCII_USTRINGPARAM( XMLN_VERSIONSLIST ) );
 

Modified: openoffice/trunk/main/xmloff/source/style/styleexp.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/xmloff/source/style/styleexp.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/xmloff/source/style/styleexp.cxx (original)
+++ openoffice/trunk/main/xmloff/source/style/styleexp.cxx Sat Jun  8 20:30:34 
2019
@@ -477,7 +477,7 @@ void XMLStyleExport::exportStyleFamily(
                                                                                
          xStyles,pPrefix );
                                if( bUsed && bFirstStyle && bExported  )
                                {
-                                       // If this is the first style, find out 
wether next styles
+                                       // If this is the first style, find out 
whether next styles
                                        // are supported.
                                        Reference< XPropertySet > xPropSet( 
xStyle, UNO_QUERY );
                                        Reference< XPropertySetInfo > 
xPropSetInfo =


Reply via email to
--- openoffice/trunk/main/shell/source/unix/exec/shellexec.cxx (original)
+++ openoffice/trunk/main/shell/source/unix/exec/shellexec.cxx Sat Jun  8 
20:30:34 2019
@@ -140,7 +140,7 @@ void SAL_CALL ShellExec::execute( const
     // DESKTOP_LAUNCH, see 
http://freedesktop.org/pipermail/xdg/2004-August/004489.html
     static const char *pDesktopLaunch = getenv( "DESKTOP_LAUNCH" );
     
     // Check wether aCommand contains a document url or not
     sal_Int32 nIndex = aCommand.indexOf( OUString( 
RTL_CONSTASCII_USTRINGPARAM(":/") ) );
     
     if( nIndex > 0 || 0 == aCommand.compareToAscii("mailto:";, 7) )

Modified: openoffice/trunk/main/svx/source/accessibility/ChildrenManagerImpl.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/accessibility/ChildrenManagerImpl.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/accessibility/ChildrenManagerImpl.cxx 
(original)
+++ openoffice/trunk/main/svx/source/accessibility/ChildrenManagerImpl.cxx Sat 
Jun  8 20:30:34 2019
@@ -146,7 +146,7 @@ uno::Reference<XAccessible>
     throw (::com::sun::star::uno::RuntimeException,
            ::com::sun::star::lang::IndexOutOfBoundsException)
 {
     // Check wether the given index is valid.
     if (nIndex < 0 || (unsigned long)nIndex >= maVisibleChildren.size())
         throw lang::IndexOutOfBoundsException (
             ::rtl::OUString::createFromAscii( "no accessible child with index 
")

Modified: openoffice/trunk/main/svx/source/accessibility/ChildrenManagerImpl.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/accessibility/ChildrenManagerImpl.hxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================
--- openoffice/trunk/main/svx/source/accessibility/ChildrenManagerImpl.hxx 
(original)
+++ openoffice/trunk/main/svx/source/accessibility/ChildrenManagerImpl.hxx Sat 
Jun  8 20:30:34 2019
@@ -292,7 +292,7 @@ public:
         @param pReplacement
             The replacement for the current child.
         @return
-            The returned value indicates wether the replacement has been
+            The returned value indicates whether the replacement has been
             finished successfully.
     */
     virtual sal_Bool ReplaceChild (
@@ -140,7 +140,7 @@ void SAL_CALL ShellExec::execute( const
     static const char *pDesktopLaunch = getenv( "DESKTOP_LAUNCH" );
     
-    // Check wether aCommand contains a document url or not
+    // Check whether aCommand contains a document url or not
     sal_Int32 nIndex = aCommand.indexOf( OUString( 
RTL_CONSTASCII_USTRINGPARAM(":/") ) );
@@ -146,7 +146,7 @@ uno::Reference<XAccessible>
            ::com::sun::star::lang::IndexOutOfBoundsException)
 {
-    // Check wether the given index is valid.
+    // Check whether the given index is valid.
     if (nIndex < 0 || (unsigned long)nIndex >= maVisibleChildren.size())
         throw lang::IndexOutOfBoundsException (

Modified: openoffice/trunk/main/svx/source/form/fmundo.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/svx/source/form/fmundo.cxx?rev=1860845&r1=1860844&r2=1860845&view=diff
==============================================================================